@@ -1,3 +1,19 @@
+"""
+    Copyright 2020 Ext-Creators
+
+    Licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
+    You may obtain a copy of the License at
+
+        http://www.apache.org/licenses/LICENSE-2.0
+
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
+    limitations under the License.
+"""
+
 """An experiment that allows you to handle all exceptions of
 group commands in the error handler of the root parent.
 
@@ -22,17 +38,20 @@ async def color(ctx):
 ```
 """
 
-from discord.ext.commands.core import Command, Cog, wrap_callback
+from discord.ext import commands
 
-async def _dispatch_error(self, ctx, error):
+
+async def dispatch_error(self, ctx, error):
     ctx.command_failed = True
     cog = self.cog
+
     try:
         coro = self.on_error
     except AttributeError:
         pass
     else:
-        injected = wrap_callback(coro)
+        injected = commands.core.wrap_callback(coro)
+
         if cog is not None:
             await injected(cog, ctx, error)
         else:
@@ -43,7 +62,8 @@ async def _dispatch_error(self, ctx, error):
     except AttributeError:
         pass
     else:
-        injected = wrap_callback(coro)
+        injected = commands.core.wrap_callback(coro)
+
         if cog is not None:
             await injected(cog, ctx, error)
         else:
@@ -51,11 +71,11 @@ async def _dispatch_error(self, ctx, error):
 
     try:
         if cog is not None:
-            local = Cog._get_overridden_method(cog.cog_command_error)
+            local = commands.Cog._get_overridden_method(cog.cog_command_error)
             if local is not None:
-                wrapped = wrap_callback(local)
+                wrapped = commands.core.wrap_callback(local)
                 await wrapped(ctx, error)
     finally:
-        ctx.bot.dispatch('command_error', ctx, error)
+        ctx.bot.dispatch("command_error", ctx, error)
 
-Command.dispatch_error = _dispatch_error
+commands.Command.dispatch_error = dispatch_error
